package WordList::EN::Common::COCA::Top1000;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2020-05-21'; # DATE
our $DIST = 'WordList-EN-Common-COCA-Top1000'; # DIST
our $VERSION = '0.001'; # VERSION

use WordList;
our @ISA = qw(WordList);

our %STATS = ("num_words_contain_whitespace",0,"num_words",1000,"longest_word_len",14,"avg_word_len",5.328,"num_words_contain_nonword_chars",2,"num_words_contain_unicode",2,"num_words_contains_whitespace",0,"num_words_contains_unicode",2,"num_words_contains_nonword_chars",2,"shortest_word_len",1); # STATS

our $SORT = 'frequency';

1;
# ABSTRACT: 1000 most common English words, from COCA

=pod

=encoding UTF-8

=head1 NAME

WordList::EN::Common::COCA::Top1000 - 1000 most common English words, from COCA

=head1 VERSION

This document describes version 0.001 of WordList::EN::Common::COCA::Top1000 (from Perl distribution WordList-EN-Common-COCA-Top1000), released on 2020-05-21.

=head1 SYNOPSIS

 use WordList::EN::Common::COCA::Top1000;

 my $wl = WordList::EN::Common::COCA::Top1000->new;

 # Pick a (or several) random word(s) from the list
 my $word = $wl->pick;
 my @words = $wl->pick(3);

 # Check if a word exists in the list
 if ($wl->word_exists('foo')) { ... }

 # Call a callback for each word
 $wl->each_word(sub { my $word = shift; ... });

 # Iterate
 my $first_word = $wl->first_word;
 while (defined(my $word = $wl->next_word)) { ... }

 # Get all the words
 my @all_words = $wl->all_words;

=head1 STATISTICS

 +----------------------------------+-------+
 | key                              | value |
 +----------------------------------+-------+
 | avg_word_len                     | 5.328 |
 | longest_word_len                 | 14    |
 | num_words                        | 1000  |
 | num_words_contain_nonword_chars  | 2     |
 | num_words_contain_unicode        | 2     |
 | num_words_contain_whitespace     | 0     |
 | num_words_contains_nonword_chars | 2     |
 | num_words_contains_unicode       | 2     |
 | num_words_contains_whitespace    | 0     |
 | shortest_word_len                | 1     |
 +----------------------------------+-------+

The statistics is available in the C<%STATS> package variable.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/WordList-EN-Common-COCA-Top1000>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-WordList-EN-Common-COCA-Top1000>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=WordList-EN-Common-COCA-Top1000>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

Source: L<https://www.espressoenglish.net/1000-most-common-words-in-english/>,
which in turn claims to use L<http://www.wordfrequency.info> (COCA).

About COCA: L<https://en.wikipedia.org/wiki/Corpus_of_Contemporary_American_English>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

__DATA__
the
be
and
of
a
in
to
have
to
it
I
that
for
you
he
with
on
do
say
this
they
at
but
we
his
from
that
not
n’t
n’t
by
she
or
as
what
go
their
can
who
get
if
would
her
all
my
make
about
know
will
as
up
one
time
there
year
so
think
when
which
them
some
me
people
take
out
into
just
see
him
your
come
could
now
than
like
other
how
then
its
our
two
more
these
want
way
look
first
also
new
because
day
more
use
no
man
find
here
thing
give
many
well
only
those
tell
one
very
her
even
back
any
good
woman
through
us
life
child
there
work
down
may
after
should
call
world
over
school
still
try
in
as
last
ask
need
too
feel
three
when
state
never
become
between
high
really
something
most
another
much
family
own
out
leave
put
old
while
mean
on
keep
student
why
let
great
same
big
group
begin
seem
country
help
talk
where
turn
problem
every
start
hand
might
American
show
part
about
against
place
over
such
again
few
case
most
week
company
where
system
each
right
program
hear
so
question
during
work
play
government
run
small
number
off
always
move
like
night
live
Mr
point
believe
hold
today
bring
happen
next
without
before
large
all
million
must
home
under
water
room
write
mother
area
national
money
story
young
fact
month
different
lot
right
study
book
eye
job
word
though
business
issue
side
kind
four
head
far
black
long
both
little
house
yes
after
since
long
provide
service
around
friend
important
father
sit
away
until
power
hour
game
often
yet
line
political
end
among
ever
stand
bad
lose
however
member
pay
law
meet
car
city
almost
include
continue
set
later
community
much
name
five
once
white
least
president
learn
real
change
team
minute
best
several
idea
kid
body
information
nothing
ago
right
lead
social
understand
whether
back
watch
together
follow
around
parent
only
stop
face
anything
create
public
already
speak
others
read
level
allow
add
office
spend
door
health
person
art
sure
such
war
history
party
within
grow
result
open
change
morning
walk
reason
low
win
research
girl
guy
early
food
before
moment
himself
air
teacher
force
offer
enough
both
education
across
although
remember
foot
second
boy
maybe
toward
able
age
off
policy
everything
love
process
music
including
consider
appear
actually
buy
probably
human
wait
serve
market
die
send
expect
home
sense
build
stay
fall
oh
nation
plan
cut
college
interest
death
course
someone
experience
behind
reach
local
kill
six
remain
effect
use
yeah
suggest
class
control
raise
care
perhaps
little
late
hard
field
else
pass
former
sell
major
sometimes
require
along
development
themselves
report
role
better
economic
effort
up
decide
rate
strong
possible
heart
drug
show
leader
light
voice
wife
whole
police
mind
finally
pull
return
free
military
price
report
less
according
decision
explain
son
hope
even
develop
view
relationship
carry
town
road
drive
arm
TRUE
federal
break
better
difference
thank
receive
value
international
building
action
full
model
join
season
society
because
tax
director
early
position
player
agree
especially
record
pick
wear
paper
special
space
ground
form
support
event
official
whose
matter
everyone
center
couple
site
end
project
hit
base
activity
star
table
need
court
produce
eat
American
teach
oil
half
situation
easy
cost
industry
figure
face
street
image
itself
phone
either
data
cover
quite
picture
clear
practice
piece
land
recent
describe
product
doctor
wall
patient
worker
news
test
movie
certain
north
love
personal
open
support
simply
third
technology
catch
step
baby
computer
type
attention
draw
film
Republican
tree
source
red
nearly
organization
choose
cause
hair
look
point
century
evidence
window
difficult
listen
soon
culture
billion
chance
brother
energy
period
course
summer
less
realize
hundred
available
plant
likely
opportunity
term
short
letter
condition
choice
place
single
rule
daughter
administration
south
husband
Congress
floor
campaign
material
population
well
call
economy
medical
hospital
church
close
thousand
risk
current
fire
future
wrong
involve
defense
anyone
increase
security
bank
myself
certainly
west
sport
board
seek
per
subject
officer
private
rest
behavior
deal
performance
fight
throw
top
quickly
past
goal
second
bed
order
author
fill
represent
focus
foreign
drop
plan
blood
upon
agency
push
nature
color
no
recently
store
reduce
sound
note
fine
before
near
movement
page
enter
share
than
common
poor
other
natural
race
concern
series
significant
similar
hot
language
each
usually
response
dead
rise
animal
factor
decade
article
shoot
east
save
seven
artist
away
scene
stock
career
despite
central
eight
thus
treatment
beyond
happy
exactly
protect
approach
lie
size
dog
fund
serious
occur
media
ready
sign
thought
list
individual
simple
quality
pressure
accept
answer
hard
resource
identify
left
meeting
determine
prepare
disease
whatever
success
argue
cup
particularly
amount
ability
staff
recognize
indicate
character
growth
loss
degree
wonder
attack
herself
region
television
box
TV
training
pretty
trade
deal
election
everybody
physical
lay
general
feeling
standard
bill
message
fail
outside
arrive
analysis
benefit
name
sex
forward
lawyer
present
section
environmental
glass
answer
skill
sister
PM
professor
operation
financial
crime
stage
ok
compare
authority
miss
design
sort
one
act
ten
knowledge
gun
station
blue
state
strategy
little
clearly
discuss
indeed
force
truth
song
example
democratic
check
environment
leg
dark
public
various
rather
laugh
guess
executive
set
study
prove
hang
entire
rock
design
enough
forget
since
claim
note
remove
manager
help
close
sound
enjoy
network
legal
religious
cold
form
final
main
science
green
memory
card
above
seat
cell
establish
nice
trial
expert
that
spring
firm
Democrat
radio
visit
management
care
avoid
imagine
tonight
huge
ball
no
close
finish
yourself
talk
theory
impact
respond
statement
maintain
charge
popular
traditional
onto
reveal
direction
weapon
employee
cultural
contain
peace
head
control
base
pain
apply
play
measure
wide
shake
fly
interview
manage
chair
fish
particular
camera
structure
politics
perform
bit
weight
suddenly
discover
candidate
top
production
treat
trip
evening
affect
inside
conference
unit
best
style
adult
worry
range
mention
rather
far
deep
past
edge
individual
specific
writer
trouble
necessary
throughout
challenge
fear
shoulder
institution
middle
sea
dream
bar
beautiful
property
instead
improve
stuff
